@@ -52,6 +52,8 @@ class Yaco(dict):
         :type data: dict
         """
         dict.__init__(self)
+        if type(data) == type("string"):
+            data = yaml.load(data)
         self.update(data)
 
     def __str__(self):
